@@ -1,9 +1,9 @@
 import re
-import six
+from typing import Any, Iterable, Iterator, List, Match, Pattern, Union, cast
 from w3lib.html import replace_entities as w3lib_replace_entities
 
 
-def flatten(x):
+def flatten(x: Iterable[Any]) -> List[Any]:
     """flatten(sequence) -> list
     Returns a single, flat list which contains all elements retrieved
     from the sequence and all recursively contained sub-sequences
@@ -21,18 +21,17 @@ def flatten(x):
     return list(iflatten(x))
 
 
-def iflatten(x):
-    """iflatten(sequence) -> iterator
+def iflatten(x: Iterable[Any]) -> Iterator[Any]:
+    """iflatten(sequence) -> Iterator
     Similar to ``.flatten()``, but returns iterator instead"""
     for el in x:
         if _is_listlike(el):
-            for el_ in flatten(el):
-                yield el_
+            yield from flatten(el)
         else:
             yield el
 
 
-def _is_listlike(x):
+def _is_listlike(x: Any) -> bool:
     """
     >>> _is_listlike("foo")
     False
@@ -50,25 +49,27 @@ def _is_listlike(x):
     True
     >>> _is_listlike((x for x in range(3)))
     True
-    >>> _is_listlike(six.moves.xrange(5))
+    >>> _is_listlike(range(5))
     True
     """
-    return hasattr(x, "__iter__") and not isinstance(x, (six.text_type, bytes))
+    return hasattr(x, "__iter__") and not isinstance(x, (str, bytes))
 
 
-def extract_regex(regex, text, replace_entities=True):
-    """Extract a list of unicode strings from the given text/encoding using the following policies:
+def extract_regex(
+    regex: Union[str, Pattern[str]], text: str, replace_entities: bool = True
+) -> List[str]:
+    """Extract a list of strings from the given text/encoding using the following policies:
     * if the regex contains a named group called "extract" that will be returned
     * if the regex contains multiple numbered groups, all those will be returned (flattened)
     * if the regex doesn't contain any group the entire regex matching is returned
     """
-    if isinstance(regex, six.string_types):
+    if isinstance(regex, str):
         regex = re.compile(regex, re.UNICODE)
 
-    if 'extract' in regex.groupindex:
+    if "extract" in regex.groupindex:
         # named group
         try:
-            extracted = regex.search(text).group('extract')
+            extracted = cast(Match[str], regex.search(text)).group("extract")
         except AttributeError:
             strings = []
         else:
@@ -80,15 +81,15 @@ def extract_regex(regex, text, replace_entities=True):
     strings = flatten(strings)
     if not replace_entities:
         return strings
-    return [w3lib_replace_entities(s, keep=['lt', 'amp']) for s in strings]
+    return [w3lib_replace_entities(s, keep=["lt", "amp"]) for s in strings]
 
 
-def shorten(text, width, suffix='...'):
+def shorten(text: str, width: int, suffix: str = "...") -> str:
     """Truncate the given text to fit in the given width."""
     if len(text) <= width:
         return text
     if width > len(suffix):
-        return text[:width-len(suffix)] + suffix
+        return text[: width - len(suffix)] + suffix
     if width >= 0:
-        return suffix[len(suffix)-width:]
-    raise ValueError('width must be equal or greater than 0')
+        return suffix[len(suffix) - width :]
+    raise ValueError("width must be equal or greater than 0")
